pub struct AdjudicationResponse {
pub handle_id: Uuid,
pub verdict: AdjudicationVerdict,
pub evidence_provenance: ProvenanceLabel,
}Expand description
Response delivered asynchronously back into the engine from the oracle.
Fields
handle_id: UuidCorrelates this response back to the originating AdjudicationRequest.
verdict: AdjudicationVerdictThe oracle’s verdict on the challenger vs incumbent dispute.
evidence_provenance: ProvenanceLabelProvenance label that the oracle used to reach this verdict.